@@ -15,12 +15,12 @@ Methods available on ``tio.exports``:
 '''
 from .base import TIOEndpoint, APIResultsIterator, UnexpectedValueError
 from tenable.errors import TioExportsError, TioExportsTimeout
-from ipaddress import IPv4Network, AddressValueError
+from ipaddress import IPv4Network
 try:
     from json.decoder import JSONDecodeError
 except ImportError:
     JSONDecodeError = ValueError
-import time, ipaddress, sys
+import time, sys
 
 class ExportsIterator(APIResultsIterator):
     '''
@@ -35,6 +35,7 @@ class ExportsIterator(APIResultsIterator):
         self.timeout = None
         self.chunks = list()
         self.processed = list()
+        self._wait_for_complete = False
         APIResultsIterator.__init__(self, api, **kw)
 
     def _process_page(self, page_data):
@@ -50,6 +51,7 @@ class ExportsIterator(APIResultsIterator):
         def get_status():
             # Query the API for the status of the export.
             status = self._api.get('{}/export/{}/status'.format(self.type, self.uuid)).json()
+            self._log.debug(f'EXPORT {self.type} {self.uuid} is status {status.get("status")}')
 
             # We need to get the list of chunks that we haven't completed yet and are
             # available for download.
@@ -65,6 +67,9 @@ class ExportsIterator(APIResultsIterator):
               and len(status['chunks_unfinished']) < 1):
                 raise StopIteration()
 
+            if status['status'] != 'FINISHED' and self._wait_for_complete:
+                status['chunks_unfinished'] = list()
+
             if status['status'] == 'ERROR':
                 raise TioExportsError(self.type, self.uuid)
 
@@ -131,8 +136,8 @@ class ExportsIterator(APIResultsIterator):
         # If we have worked through the current page of records then we should
         # query the next page of records.
         if self.page_count >= len(self.page):
-            self.page_count = 0
             self._get_page()
+            self.page_count = 0
 
         # Get the relevant record, increment the counters, and return the
         # record.
@@ -163,6 +168,10 @@ class ExportsAPI(TIOEndpoint):
             first_found (int, optional):
                 Specifies the earliest time for a vulnerability to have been
                 discovered.  Format is a unix timestamp integer.
+            include_unlicensed (bool, optional):
+                Informs the vuln export if it should include vulnerability data
+                from assets that are unlicensed.  This is generally required
+                when interacting with stale assets (>90 days).
             last_fixed (int, optional):
                 Specifies the earliest time that vulnerabilities may have been
                 fixed.  Format is a unix timestamp integer.
@@ -172,39 +181,50 @@ class ExportsAPI(TIOEndpoint):
             num_assets (int, optional):
                 Specifies the number of assets returned per-chunk.  If nothing is
                 specified, it will default to 500 assets.
-            plugin_family (list, optional):
+            plugin_family (list[str], optional):
                 list of plugin families to restrict the export to.  Please note
                 that this parameter's values are case sensitive.
-            severity (list, optional):
+            plugin_ids (list[int], optional):
+                A list of plugin id's to explicitly export.
+            severity (list[str], optional):
                 list of severities to include as part of the export.  Supported
                 values are `info`, `low`, `medium`, `high`, and `critical`.
-            since (int, optional):
-                Returned results will be bounded based on the state of the
-                vulnerability instance detailed below.  This parameter expects a
-                unix timestamp.
-
-                * Vulns in the **open** state are bounded by ``first_found``.
-                * Vulns in the **reopened** state are bounded by ``last_found``.
-                * Vulns in the **fixed** state are bounded by ``last_fixed``.
-
-                In short it'll return active vulnerabilities based on when they
-                were first discovered, and fixed and resurfaced vulnerabilities
-                based on when they were last observed.  The idea is to relay
-                state changes of a vulnerability and use a singular export to
-                track all of these state changes.
-            state (list, optional):
+            state (list[str], optional):
                 list of object states to be returned.  Supported values are
                 `open`, `reopened`, and `fixed`.
-            tags (list, optional):
+            tags (list[tuple], optional):
                 List of tag key-value pairs that must be associated to the
                 vulnerability data to be returned.  Key-value pairs are tuples
                 ``('key', 'value')`` and are case-sensitive.
+            timeout (int, optional):
+                Number of seconds to wait before timing out the export.  If left
+                unspecified the iterator will wait indefinitely for the export to
+                complete.
             uuid (str, optional):
                 To re-request an iterator based off of an existing export, pass
                 the UUID of the export to bypass the initial request and instead
                 use the UUID passed to build the export iterator.
             vpr (dict, optional):
-                Restricts the results to the
+                Restricts the results to the export to only vulnerabilities that
+                match the VPR criteria specified.  As this supports a range of
+                operations, it's worth detailing a couple of examples:
+
+                VPR Scores greater than or equal to 7.0:
+
+                .. python::
+
+                    vpr={'gte': 7}
+
+                VPR Score less than 7, but not 5:
+
+                .. python::
+
+                    vpr={'lt': 7, 'neq': [5]}
+
+            when_done (bool, optional):
+                Wait to start working through the data until the export has finished
+                processing.  If left unspecified the default behavior is to download
+                chunks as they are available.
 
         Returns:
             :obj:`ExportIterator`:
@@ -232,12 +252,21 @@ class ExportsAPI(TIOEndpoint):
         for option in ['since', 'first_found', 'last_found',
                        'last_fixed', 'first_scan_time',
                        'last_authenticated_scan_time', 'last_assessed']:
-            if option in kw and self._check(option, kw[option], int):
+            self._api._log.debug(f'{option}={kw.get(option)}')
+            if self._check(option, kw.get(option), int) is not None:
                 payload['filters'][option] = kw[option]
 
         payload['num_assets'] = str(self._check('num_assets',
             kw['num_assets'] if 'num_assets' in kw else None, int, default=500))
 
+        if self._check('include_unlicensed', kw.get('include_unlicensed'), bool):
+            payload['include_unlicensed'] = kw.get('include_unlicensed')
+
+        if self._check('plugin_ids', kw.get('plugin_ids'), list):
+            payload['filters']['plugin_id'] = [int(p) for p in kw['plugin_ids']]
+        if self._check('plugin_id', kw.get('plugin_id'), list):
+            payload['filters']['plugin_id'] = [int(p) for p in kw['plugin_id']]
+
         if 'severity' in kw and self._check('severity', kw['severity'], list,
                 choices=['info', 'low', 'medium', 'high', 'critical'], case='lower'):
             payload['filters']['severity'] = kw['severity']
@@ -301,7 +330,8 @@ class ExportsAPI(TIOEndpoint):
         return ExportsIterator(self._api,
             type='vulns',
             uuid=uuid,
-            timeout=self._check('timeout', kw.get('timeout'), int)
+            timeout=self._check('timeout', kw.get('timeout'), int),
+            _wait_for_cmplete=self._check('when_done', kw.get('when_done'), bool, default=False)
         )
 
     def assets(self, **kw):
@@ -325,6 +355,18 @@ class ExportsAPI(TIOEndpoint):
             first_scan_time (int, optional):
                 Returns all assets first scanned after the specified unix
                 timestamp.
+            is_deleted (bool, optional):
+                Determines whether or not to return assets which have any value
+                within the ``deleted_at`` attribute.  If left unspecified, the
+                default is ``False``
+            is_licensed (bool, optional):
+                Determines whether or not to return unlicensed assets as part of
+                the export.  If left unspecified, the default is ``True``,
+                meaning only licensed assets will be returned.
+            is_terminated (bool, optional):
+                Determines whether or not to return assets that have any value
+                within the ``terminated_at`` attribute.  If left unspecified,
+                the default is ``False``.
             last_authenticated_scan_time (int, optional):
                 Returns all assets that have completed an authenticated scan
                 after the specified unix timestamp.
@@ -335,7 +377,7 @@ class ExportsAPI(TIOEndpoint):
                 If set to True, will return only assets that have a ServiceNow
                 Sys ID.  If set to False, then returns only assets that do not
                 have a ServiceNow Sys ID.
-            sources (list, optional):
+            sources (list[str], optional):
                 Returns assets that have the specified source.  If multiple
                 sources are listed, then the results will be assets that have
                 been observed by any of the sources listed.
@@ -344,14 +386,22 @@ class ExportsAPI(TIOEndpoint):
                 returns only assets that do not have any plugin results.  Assets
                 thats would not have plugin results would be assets created from
                 a connector, or a discovery scan.
-            tags (list, optional):
+            tags (list[tuple], optional):
                 List of tag key-value pairs that must be associated to the
                 asset data to be returned.  Key-value pairs are tuples
                 ``('key', 'value')`` and are case-sensitive.
+            timeout (int, optional):
+                Number of seconds to wait before timing out the export.  If left
+                unspecified the iterator will wait indefinitely for the export to
+                complete.
             uuid (str, optional):
                 To re-request an iterator based off of an existing export, pass
                 the UUID of the export to bypass the initial request and instead
                 use the UUID passed to build the export iterator.
+            when_done (bool, optional):
+                Wait to start working through the data until the export has finished
+                processing.  If left unspecified the default behavior is to download
+                chunks as they are available.
 
         Returns:
             :obj:`ExportIterator`:
@@ -390,7 +440,8 @@ class ExportsAPI(TIOEndpoint):
 
         # Lets to the same thing we did above for integer checks for the boolean
         # ones as well.
-        for option in ['servicenow_sysid', 'has_plugin_results']:
+        for option in ['servicenow_sysid', 'has_plugin_results',
+                       'is_terminated', 'is_deleted', 'is_licensed']:
             if option in kw:
                 payload['filters'][option] = self._check(option, kw[option], bool)
 
@@ -420,4 +471,10 @@ class ExportsAPI(TIOEndpoint):
             uuid = self._api.post(
                 'assets/export', json=payload).json()['export_uuid']
             self._api._log.debug('Initiated asset export {}'.format(uuid))
-        return ExportsIterator(self._api, type='assets', uuid=uuid)
+        return ExportsIterator(
+            self._api,
+            type='assets',
+            uuid=uuid,
+            timeout=self._check('timeout', kw.get('timeout'), int),
+            _wait_for_cmplete=self._check('when_done', kw.get('when_done'), bool, default=False)
+        )
